package rs.core.example;




import rs.core.CoreInterface;
import rs.core.Utils;
import rs.core.example.ui.Startup;
import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.os.Parcelable;
import android.os.RemoteException;
import android.widget.Toast;

public class Main extends Activity implements RSCoreConnection {
	
	
	
	
	private final String MESSAGE_TAG = getClass().getPackage().getName()+"."+hashCode();
	private static final String DATA_EXTRA = "Data";
	private static final String SENDER_EXTRA = "Sender";

	private RSCoreListener _listener;
	
	private BroadcastReceiver CORE_EVENT_RECEIVER = new BroadcastReceiver() {
		@Override
		public void onReceive(Context context, Intent intent) {
			Parcelable data = intent.getParcelableExtra(DATA_EXTRA);
			if(_listener != null)
				_listener.onCoreEvent(intent.getStringExtra(SENDER_EXTRA), data);
			
		}
	};
		
	
	private class CoreServiceConnector implements ServiceConnection {
		private CoreInterface _RSCore;
		@Override
		public void onServiceConnected(ComponentName name, IBinder service) {
			_RSCore = CoreInterface.Stub.asInterface(service);
			
			try {
				_RSCore.subscribe(MESSAGE_TAG);
				String sDevices = _RSCore.availableDevices();
				String sModel = _RSCore.getDeviceModel();
				String serial = _RSCore.getDeviceSerial();
				System.out.println(sDevices+" "+sModel+" "+serial);
				getFragmentManager().beginTransaction().replace(R.id.v_content, new Startup()).commit();
			} catch(RemoteException re) {
				Toast.makeText(Main.this, "Ошибка при вызове метода RSCore "+re.getLocalizedMessage(), Toast.LENGTH_LONG).show();
				
			}
		}

		@Override
		public void onServiceDisconnected(ComponentName name) {
			try {
				_RSCore.unsubscribe(MESSAGE_TAG);
			} catch(RemoteException re) { }

			_RSCore = null;
			
		}
		
	}
	@Override
	public void onBackPressed() {
		if(getFragmentManager().getBackStackEntryCount() > 0)
			getFragmentManager().popBackStack();
		else
			super.onBackPressed();
	}

	private CoreServiceConnector CORE_CONNECTOR = new CoreServiceConnector();
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		registerReceiver(CORE_EVENT_RECEIVER, new IntentFilter(MESSAGE_TAG));
		if(! bindService(new Intent(Utils.CORE_SERVICE_INTENT), CORE_CONNECTOR, BIND_AUTO_CREATE) )
			Toast.makeText(Main.this, "Ошибка подключения к RSCore", Toast.LENGTH_LONG).show();
	}
	@Override
	protected void onDestroy() {
		unregisterReceiver(CORE_EVENT_RECEIVER);
		unbindService(CORE_CONNECTOR);
		super.onDestroy();
	}
	@Override
	public void setListener(RSCoreListener l) {
		_listener = l;
		
	}
	@Override
	protected void onStart() {
		super.onStart();
		
	}
	@Override
	protected void onStop() {
		super.onStop();
	}
	@Override
	public void removeListener(RSCoreListener l) {
		if(_listener == l)
			_listener = null;
	}
	@Override
	public CoreInterface getRSCore() {
		return CORE_CONNECTOR._RSCore;
	}

}
