package rs.core.example.ui;

import rs.core.CoreInterface;
import rs.core.example.R;
import rs.core.example.RSCoreConnection;
import rs.core.example.RSCoreListener;
import rs.core.hw.Barcode;
import rs.core.hw.DeviceData;
import rs.core.hw.NfcTag;
import android.app.Fragment;
import android.content.Context;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.os.Parcelable;
import android.os.RemoteException;
import android.os.Vibrator;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.TextView;
import android.widget.Toast;

public class DataReceiver extends Fragment implements RSCoreListener, MediaPlayer.OnCompletionListener {

	private static final String DEVICE_TAG = "device";
	
	protected String device;
	protected TextView dataText;
	private CheckBox vibro, sound;
	private Vibrator VIBRATOR;
	protected CoreInterface core;
	
	public static DataReceiver newInstance(String device) {
		DataReceiver result = new DataReceiver();
		result.device = device;
		return result;
	}
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		if(savedInstanceState != null)
			device = savedInstanceState.getString(DEVICE_TAG);
		
	}
	public DataReceiver() {
	}
	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
			Bundle savedInstanceState) {
		return inflater.inflate(R.layout.data, container,false);
	}
	@Override
	public void onViewCreated(View view, Bundle savedInstanceState) {
		dataText = (TextView)view.findViewById(R.id.lbl_data);
		vibro = (CheckBox)view.findViewById(R.id.cb_vibro);
		sound = (CheckBox)view.findViewById(R.id.cb_sound);
	}
	@Override
	public void onStart() {
		super.onStart();
		VIBRATOR = (Vibrator)getActivity().getSystemService(Context.VIBRATOR_SERVICE);
		if(!VIBRATOR.hasVibrator())
			VIBRATOR = null;
		RSCoreConnection CoreConnection = (RSCoreConnection)getActivity(); 
		core = CoreConnection.getRSCore();
		try {
			if(!core.isDeviceAvailable(device))  {
				Toast.makeText(getActivity(), "Устройство не доступно", Toast.LENGTH_LONG).show();
				return;
			}
			core.setDeviceEnabled(device, true);
			CoreConnection.setListener(this);
		} catch(RemoteException re) {
			Toast.makeText(getActivity(), "Ошибка вызова RSCore", Toast.LENGTH_LONG).show();
		}
	}
	@Override
	public void onStop() {
		((RSCoreConnection)getActivity()).removeListener(this);
		super.onStop();
	}
	@Override
	public void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);
		outState.putString(DEVICE_TAG, device);
	}
	@Override
	public void onDestroy() {
		super.onDestroy();
	}
	@SuppressWarnings("deprecation")
	@Override
	public void onCoreEvent(String sender, Parcelable data) {
		if(device.equalsIgnoreCase(sender)) {
			if(data instanceof Barcode) {
				Barcode b = (Barcode)data;
				dataText.setText(b.value+" "+b.type.name()+" ("+b.type.ordinal()+")");
			} else if(data instanceof NfcTag)
				dataText.setText(((NfcTag)data).tagId());
			else if(data instanceof KeyEvent) 
				dataText.setText(String.valueOf(((KeyEvent)data).getKeyCode()));
			if(sound.isChecked())
				try {
					MediaPlayer p = MediaPlayer.create(getActivity(),R.raw.beep);
					p.setOnCompletionListener(this);
					p.start();
				} catch (Exception e) {
				    e.printStackTrace();
				}
			if(vibro.isChecked() && VIBRATOR!=null)
				VIBRATOR.vibrate(200);
			if(data instanceof DeviceData)
				onReceivedData((DeviceData)data);
		}
		
	}
	
	protected void onReceivedData(DeviceData data) { }
	
	@Override
	public void onCompletion(MediaPlayer mp) {
		mp.release();
		
	}

}
